package com.example;

import com.example.dao.common.RequestLogDao;
import com.example.pojo.po.common.RequestLogPo;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.IOUtils;
import org.apache.poi.ss.usermodel.ClientAnchor;
import org.apache.poi.ss.usermodel.Drawing;
import org.apache.poi.ss.usermodel.Picture;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFClientAnchor;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.List;
import java.util.Map;

@Slf4j
@SpringBootTest
@ActiveProfiles("dev")
class GdcFinanceApiApplicationTests {

    @Autowired
    RequestLogDao requestLogDao;

    @Test
    void contextLoads() {
        Gson gson = new Gson();
        List<RequestLogPo> list = requestLogDao.selectList(null);
        for (RequestLogPo requestLogPo : list) {
            Map<String, String> map = gson.fromJson(requestLogPo.getRequestParameters(), new TypeToken<>() {});
            System.out.println(map);
        }
    }

    public static void main(String[] args) {
        try(FileInputStream fis = new FileInputStream("input.xlsx");
            Workbook workbook = new XSSFWorkbook(fis);
            FileOutputStream fos = new FileOutputStream("output.xlsx");
            ) {
            // 读取水印图片
            byte[] watermarkBytes = IOUtils.toByteArray(new FileInputStream("watermark.png"));
            int pictureIndex = workbook.addPicture(watermarkBytes, Workbook.PICTURE_TYPE_PNG);

            // 获取第一个工作表
            Sheet sheet = workbook.getSheetAt(0);

            // 设置水印图片的位置和大小
            ClientAnchor anchor = new XSSFClientAnchor();
            anchor.setCol1(0);
            anchor.setRow1(0);
            anchor.setCol2(sheet.getColumnWidth(0));
            anchor.setRow2((int) sheet.getRow(0).getHeightInPoints());

            // 添加水印图片到工作表
            Drawing drawing = sheet.createDrawingPatriarch();
            Picture picture = drawing.createPicture(anchor, pictureIndex);
            picture.resize();
            // 保存带有水印的Excel文件
            workbook.write(fos);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
    }
}
